]> granicus.if.org Git - neomutt/commitdiff
doxygen: sort out Email descriptions
authorRichard Russon <rich@flatcap.org>
Fri, 16 Nov 2018 11:42:31 +0000 (11:42 +0000)
committerRichard Russon <rich@flatcap.org>
Fri, 16 Nov 2018 12:33:05 +0000 (12:33 +0000)
23 files changed:
commands.c
copy.c
edit.c
editmsg.c
email/envelope.c
email/parse.c
email/thread.c
flags.c
hcache/serialize.c
hook.c
imap/message.c
imap/util.c
maildir/mh.c
mutt_attach.c
mutt_header.c
mutt_thread.c
mx.c
mx.h
pop/pop.c
postpone.c
recvcmd.c
score.c
send.c

index 2a49e03ef6abd5873b11dc369a86f616efce6728..da364a8a3e02547c81e9ba46d92e0a67ab7bf259 100644 (file)
@@ -555,7 +555,7 @@ static int pipe_message(struct Email *e, char *cmd, bool decode, bool print,
 
 /**
  * mutt_pipe_message - Pipe a message
- * @param e Header of message to pipe
+ * @param e Email to pipe
  */
 void mutt_pipe_message(struct Email *e)
 {
@@ -827,7 +827,7 @@ static void set_copy_flags(struct Email *e, bool decode, bool decrypt,
 
 /**
  * mutt_save_message_ctx - Save a message to a given mailbox
- * @param e       Header of message
+ * @param e       Email
  * @param delete  If true, delete the original
  * @param decode  If true, decode the message
  * @param decrypt If true, decrypt the message
diff --git a/copy.c b/copy.c
index 05fc27d984012b5351eb9d6fdf8dcf1d25b94672..9888f74040b870c8f46df1181c5a4c385dc77fad 100644 (file)
--- a/copy.c
+++ b/copy.c
@@ -371,9 +371,9 @@ int mutt_copy_hdr(FILE *in, FILE *out, LOFF_T off_start, LOFF_T off_end,
 }
 
 /**
- * mutt_copy_header - Copy email header
+ * mutt_copy_header - Copy Email header
  * @param in     FILE pointer to read from
- * @param e      Email Header
+ * @param e      Email
  * @param out    FILE pointer to write to
  * @param flags  Flags, see below
  * @param prefix Prefix for quoting headers
@@ -566,7 +566,7 @@ static int count_delete_lines(FILE *fp, struct Body *b, LOFF_T *length, size_t d
  * mutt_copy_message_fp - make a copy of a message from a FILE pointer
  * @param fpout   Where to write output
  * @param fpin    Where to get input
- * @param e     Header of message being copied
+ * @param e       Email being copied
  * @param flags   See below
  * @param chflags Flags to mutt_copy_header()
  * @retval  0 Success
@@ -780,7 +780,7 @@ int mutt_copy_message_fp(FILE *fpout, FILE *fpin, struct Email *e, int flags, in
  * mutt_copy_message_ctx - Copy a message from a Context
  * @param fpout   FILE pointer to write to
  * @param src     Source mailbox
- * @param e     Email Header
+ * @param e       Email
  * @param flags   Flags, see: mutt_copy_message_fp()
  * @param chflags Header flags, see: mutt_copy_header()
  * @retval  0 Success
@@ -812,7 +812,7 @@ int mutt_copy_message_ctx(FILE *fpout, struct Context *src, struct Email *e,
  * @param dest    destination mailbox
  * @param fpin    where to get input
  * @param src     source mailbox
- * @param e     message being copied
+ * @param e       Email being copied
  * @param flags   mutt_open_copy_message() flags
  * @param chflags mutt_copy_header() flags
  * @retval  0 Success
@@ -854,7 +854,7 @@ static int append_message(struct Context *dest, FILE *fpin, struct Context *src,
  * mutt_append_message - Append a message
  * @param dest    Destination Mailbox
  * @param src     Source Mailbox
- * @param e     Email Header
+ * @param e       Email
  * @param cmflags mutt_open_copy_message() flags
  * @param chflags mutt_copy_header() flags
  * @retval  0 Success
diff --git a/edit.c b/edit.c
index 529ada1f55815218c1c6a95485815c53aa859fcc..5d59e68dfc6f324ad74964419bb4f29cb66844d7 100644 (file)
--- a/edit.c
+++ b/edit.c
@@ -298,7 +298,7 @@ static void be_print_header(struct Envelope *env)
 
 /**
  * be_edit_header - Edit the message headers
- * @param e     Message headers
+ * @param e     Email
  * @param force override the $ask* vars (used for the ~h command)
  */
 static void be_edit_header(struct Envelope *e, bool force)
index 55b9a3b027388d847403d23d11c8672f08fc1447..8c11f74cd3d80d641dbafee205e150649ef19406 100644 (file)
--- a/editmsg.c
+++ b/editmsg.c
@@ -264,7 +264,7 @@ bail:
  * edit_or_view_message - Edit an email or view it in an external editor
  * @param edit true: Edit the email; false: view the email
  * @param ctx  Mailbox Context
- * @param e   Email Header
+ * @param e   Email
  * @retval 1  Message not modified
  * @retval 0  Message edited successfully
  * @retval -1 Error
@@ -289,7 +289,7 @@ int edit_or_view_message(bool edit, struct Context *ctx, struct Email *e)
 /**
  * mutt_edit_message - Edit a message
  * @param ctx Mailbox Context
- * @param e Email Header
+ * @param e Email
  * @retval 1  Message not modified
  * @retval 0  Message edited successfully
  * @retval -1 Error
@@ -302,7 +302,7 @@ int mutt_edit_message(struct Context *ctx, struct Email *e)
 /**
  * mutt_view_message - Edit a message
  * @param ctx Mailbox Context
- * @param e Email Header
+ * @param e Email
  * @retval 1  Message not modified
  * @retval 0  Message edited successfully
  * @retval -1 Error
index c13f7268c9aeb852a1ef219380e9f924dd379694..d98ba16c72f69363078dad0aa76f601adf20358c 100644 (file)
@@ -193,19 +193,19 @@ bool mutt_env_cmp_strict(const struct Envelope *e1, const struct Envelope *e2)
 
 /**
  * mutt_env_to_local - Convert an Envelope's Address fields to local format
- * @param e Envelope to modify
+ * @param env Envelope to modify
  *
  * Run mutt_addrlist_to_local() on each of the Address fields in the Envelope.
  */
-void mutt_env_to_local(struct Envelope *e)
+void mutt_env_to_local(struct Envelope *env)
 {
-  mutt_addrlist_to_local(e->return_path);
-  mutt_addrlist_to_local(e->from);
-  mutt_addrlist_to_local(e->to);
-  mutt_addrlist_to_local(e->cc);
-  mutt_addrlist_to_local(e->bcc);
-  mutt_addrlist_to_local(e->reply_to);
-  mutt_addrlist_to_local(e->mail_followup_to);
+  mutt_addrlist_to_local(env->return_path);
+  mutt_addrlist_to_local(env->from);
+  mutt_addrlist_to_local(env->to);
+  mutt_addrlist_to_local(env->cc);
+  mutt_addrlist_to_local(env->bcc);
+  mutt_addrlist_to_local(env->reply_to);
+  mutt_addrlist_to_local(env->mail_followup_to);
 }
 
 /* Note that `a' in the `env->a' expression is macro argument, not
index fa671da3a431939fe07b7c113cdaca9f0156bffb..204ec593de05b44c049930847345bd9dd53619cc 100644 (file)
@@ -958,7 +958,7 @@ char *mutt_rfc822_read_line(FILE *f, char *line, size_t *linelen)
 /**
  * mutt_rfc822_read_header - parses an RFC822 header
  * @param f         Stream to read from
- * @param e         Header structure of current message (optional)
+ * @param e         Current Email (optional)
  * @param user_hdrs If set, store user headers
  *                  Used for recall-message and postpone modes
  * @param weed      If this parameter is set and the user has activated the
index 169a9fbf81a98b561e566d4f641f8bc095e5da0d..98341afbb2aef8cb1312324fa8bf74499b76eee4 100644 (file)
@@ -212,7 +212,7 @@ void clean_references(struct MuttThread *brk, struct MuttThread *cur)
 
 /**
  * mutt_break_thread - Break the email Thread
- * @param e Email Header to break at
+ * @param e Email to break at
  */
 void mutt_break_thread(struct Email *e)
 {
diff --git a/hook.c b/hook.c
index 46118a33f6d585e8a572926d05ea8a1567375951..e0fe93790c6e39c52013f6cfc34e959734117ea1 100644 (file)
--- a/hook.c
+++ b/hook.c
@@ -431,7 +431,7 @@ char *mutt_find_hook(int type, const char *pat)
 /**
  * mutt_message_hook - Perform a message hook
  * @param ctx Mailbox Context
- * @param e Email Header
+ * @param e   Email
  * @param type Hook type, e.g. #MUTT_MESSAGE_HOOK
  */
 void mutt_message_hook(struct Context *ctx, struct Email *e, int type)
@@ -483,7 +483,7 @@ void mutt_message_hook(struct Context *ctx, struct Email *e, int type)
  * @param pathlen Length of buffer
  * @param type    Type e.g. #MUTT_FCC_HOOK
  * @param ctx     Mailbox Context
- * @param e     Email Header
+ * @param e       Email
  * @retval  0 Success
  * @retval -1 Failure
  */
@@ -517,7 +517,7 @@ static int addr_hook(char *path, size_t pathlen, int type, struct Context *ctx,
  * mutt_default_save - Find the default save path for an email
  * @param path    Buffer for the path
  * @param pathlen Length of buffer
- * @param e       Email Header
+ * @param e       Email
  */
 void mutt_default_save(char *path, size_t pathlen, struct Email *e)
 {
@@ -551,7 +551,7 @@ void mutt_default_save(char *path, size_t pathlen, struct Email *e)
  * mutt_select_fcc - Select the FCC path for an email
  * @param path    Buffer for the path
  * @param pathlen Length of the buffer
- * @param e       Email Header
+ * @param e       Email
  */
 void mutt_select_fcc(char *path, size_t pathlen, struct Email *e)
 {
index 4b753bd806e91d7789cd0444be0a7ab22e46b818..76b7d6db98192790a72469ff5efae07268d5e884 100644 (file)
@@ -126,7 +126,7 @@ static struct BodyCache *msg_cache_open(struct ImapAccountData *adata)
 /**
  * msg_cache_get - Get the message cache entry for an email
  * @param adata Imap Account data
- * @param e     Email header
+ * @param e     Email
  * @retval ptr  Success, handle of cache entry
  * @retval NULL Failure
  */
@@ -144,7 +144,7 @@ static FILE *msg_cache_get(struct ImapAccountData *adata, struct Email *e)
 /**
  * msg_cache_put - Put an email into the message cache
  * @param adata Imap Account data
- * @param e     Email header
+ * @param e     Email
  * @retval ptr  Success, handle of cache entry
  * @retval NULL Failure
  */
@@ -162,7 +162,7 @@ static FILE *msg_cache_put(struct ImapAccountData *adata, struct Email *e)
 /**
  * msg_cache_commit - Add to the message cache
  * @param adata Imap Account data
- * @param e     Email header
+ * @param e     Email
  * @retval  0 Success
  * @retval -1 Failure
  */
@@ -632,7 +632,7 @@ static void imap_fetch_msn_seqset(struct Buffer *b, struct ImapAccountData *adat
 /**
  * set_changed_flag - Have the flags of an email changed
  * @param[in]  ctx            Mailbox
- * @param[in]  e              Email Header
+ * @param[in]  e              Email
  * @param[in]  local_changes  Has the local mailbox been changed?
  * @param[out] server_changes Set to 1 if the flag has changed
  * @param[in]  flag_name      Flag to check, e.g. #MUTT_FLAG
@@ -1691,7 +1691,7 @@ out:
 /**
  * imap_cache_del - Delete an email from the body cache
  * @param adata Imap Account data
- * @param e     Email header
+ * @param e     Email
  * @retval  0 Success
  * @retval -1 Failure
  */
@@ -1722,7 +1722,7 @@ int imap_cache_clean(struct ImapAccountData *adata)
 /**
  * imap_set_flags - fill the message header according to the server flags
  * @param[in]  adata          Imap Account data
- * @param[in]  e              Email Header
+ * @param[in]  e              Email
  * @param[in]  s              Command string
  * @param[out] server_changes Flags have changed
  * @retval ptr  The end of flags string
index 318444a09c84e030cba0d17b9cc13e950f0fe6de..6d9ba40cf2b187c5decbb386a73cdd26f0409687 100644 (file)
@@ -448,7 +448,7 @@ struct Email *imap_hcache_get(struct ImapAccountData *adata, unsigned int uid)
 /**
  * imap_hcache_put - Add an entry to the header cache
  * @param adata Imap Account data
- * @param e     Email Header
+ * @param e     Email
  * @retval  0 Success
  * @retval -1 Failure
  */
index a1f5ecd0c8213b98c48aaaea35296268b566436a..cf467ea4ad5e0a5f975f0e2cb22d516895edf23a 100644 (file)
@@ -1349,7 +1349,7 @@ static int maildir_mh_open_message(struct Mailbox *m, struct Message *msg,
  * mh_commit_msg - Commit a message to an MH folder
  * @param m   Mailbox
  * @param msg Message to commit
- * @param e   Email Header
+ * @param e   Email
  * @param updseq  If true, update the sequence number
  * @retval  0 Success
  * @retval -1 Failure
@@ -1995,8 +1995,8 @@ void maildir_parse_flags(struct Email *e, const char *path)
  * @param f      Mesage file handle
  * @param fname  Message filename
  * @param is_old true, if the email is old (read)
- * @param e      Email Header to populate (OPTIONAL)
- * @retval ptr Populated email Header
+ * @param e      Email
+ * @retval ptr Populated Email
  *
  * Actually parse a maildir message.  This may also be used to fill
  * out a fake header structure generated by lazy maildir parsing.
@@ -2037,8 +2037,8 @@ struct Email *maildir_parse_stream(enum MailboxType magic, FILE *f,
  * @param magic  Mailbox type, e.g. #MUTT_MAILDIR
  * @param fname  Message filename
  * @param is_old true, if the email is old (read)
- * @param e      Email Header to populate (OPTIONAL)
- * @retval ptr Populated email Header
+ * @param e      Email to populate (OPTIONAL)
+ * @retval ptr Populated Email
  *
  * This may also be used to fill out a fake header structure generated by lazy
  * maildir parsing.
index c91ed6c7aa8841f539a120fa5b89572d142d9a5b..fcf32f43c2b1e2583ba6f30b36bcb61da22f54c6 100644 (file)
@@ -360,7 +360,7 @@ void mutt_check_lookup_list(struct Body *b, char *type, size_t len)
  * @param fp     Source file stream. Can be NULL
  * @param a      The message body containing the attachment
  * @param flag   Option flag for how the attachment should be viewed
- * @param e    Message header for the current message. Can be NULL
+ * @param e      Current Email. Can be NULL
  * @param actx   Attachment context
  * @retval 0   If the viewer is run and exited successfully
  * @retval -1  Error
@@ -778,7 +778,7 @@ static FILE *save_attachment_open(char *path, int flags)
  * @param m     Email Body
  * @param path  Where to save the attachment
  * @param flags Flags, e.g. #MUTT_SAVE_APPEND
- * @param e   Message header for the current message. Can be NULL
+ * @param e     Current Email. Can be NULL
  * @retval  0 Success
  * @retval -1 Error
  */
index cf654c38f582f00ad35935501054930c904b66f7..1cde7fb8e5cfaf3f6dd5d68bb89e0fe71cabea24 100644 (file)
@@ -379,7 +379,7 @@ void mutt_make_label_hash(struct Mailbox *m)
 /**
  * mutt_label_hash_add - Add a message's labels to the Hash Table
  * @param m Mailbox
- * @param e Header of message
+ * @param e Email
  */
 void mutt_label_hash_add(struct Mailbox *m, struct Email *e)
 {
@@ -392,7 +392,7 @@ void mutt_label_hash_add(struct Mailbox *m, struct Email *e)
 /**
  * mutt_label_hash_remove - Rmove a message's labels from the Hash Table
  * @param m Mailbox
- * @param e Header of message
+ * @param e Email
  */
 void mutt_label_hash_remove(struct Mailbox *m, struct Email *e)
 {
index b7e530406d74cf16b8c7743a3c0fe38f532371e8..6704faa494a4baa8202d1923b6ca53657adfd664 100644 (file)
@@ -52,7 +52,7 @@ bool ThreadReceived; ///< Config: Sort threaded messages by their received date
 
 /**
  * is_visible - Is the message visible?
- * @param e Header of message
+ * @param e   Email
  * @param ctx Mailbox
  * @retval true If the message is not hidden in some way
  */
@@ -1069,7 +1069,7 @@ void mutt_sort_threads(struct Context *ctx, bool init)
 
 /**
  * mutt_aside_thread - Find the next/previous (sub)thread
- * @param e        Search from this message
+ * @param e          Search from this Email
  * @param forwards   Direction to search: 'true' forwards, 'false' backwards
  * @param subthreads Search subthreads: 'true' subthread, 'false' not
  * @retval num Index into the virtual email table
@@ -1133,7 +1133,7 @@ int mutt_aside_thread(struct Email *e, bool forwards, bool subthreads)
 /**
  * mutt_parent_message - Find the parent of a message
  * @param ctx       Mailbox
- * @param e       Header of current message
+ * @param e         Current Email
  * @param find_root If true, find the root message
  * @retval >=0 Virtual index number of parent/root message
  * @retval -1 Error
diff --git a/mx.c b/mx.c
index 53bcba3a541ef8ef34fbdf05f77429e78208a7d4..29321c0cdde6f39aec07fc63ce511d899b792cf9 100644 (file)
--- a/mx.c
+++ b/mx.c
@@ -1043,7 +1043,7 @@ int mx_mbox_sync(struct Context *ctx, int *index_hint)
 /**
  * mx_msg_open_new - Open a new message
  * @param ctx   Destination mailbox
- * @param e   Message being copied (required for maildir support, because the filename depends on the message flags)
+ * @param e     Message being copied (required for maildir support, because the filename depends on the message flags)
  * @param flags Flags, e.g. #MUTT_SET_DRAFT
  * @retval ptr New Message
  */
@@ -1376,7 +1376,7 @@ int mx_tags_edit(struct Context *ctx, const char *tags, char *buf, size_t buflen
 /**
  * mx_tags_commit - save tags to the mailbox
  * @param ctx  Mailbox
- * @param e  Email Header
+ * @param e  Email
  * @param tags Tags to save
  * @retval  0 Success
  * @retval -1 Failure
diff --git a/mx.h b/mx.h
index e122c07e7d54388ad2b79a69bfa8748faf7e9e44..56b8f853bd4794b0aa0ad9f5d60c7e2dc46e764a 100644 (file)
--- a/mx.h
+++ b/mx.h
@@ -168,8 +168,8 @@ struct MxOps
   /**
    * msg_open_new - Open a new message in a mailbox
    * @param ctx Mailbox
-   * @param msg  Message to open
-   * @param e Email header
+   * @param msg Message to open
+   * @param e   Email
    * @retval  0 Success
    * @retval -1 Failure
    */
@@ -210,7 +210,7 @@ struct MxOps
   /**
    * tags_commit - Save the tags to a message
    * @param ctx Mailbox
-   * @param e Email Header
+   * @param e Email
    * @param buf Buffer containing tags
    * @retval  0 Success
    * @retval -1 Failure
index 85ebe4b9aa1e07e74e8ba0ade696414d27137568..57ea571d7324426c1bae740a850e5b19b4979e8f 100644 (file)
--- a/pop/pop.c
+++ b/pop/pop.c
@@ -172,7 +172,7 @@ static int fetch_message(char *line, void *file)
 /**
  * pop_read_header - Read header
  * @param adata POP Account data
- * @param e     Email header
+ * @param e     Email
  * @retval  0 Success
  * @retval -1 Connection lost
  * @retval -2 Invalid command or execution error
index 1765b19f1918264064765c066ed40922a9342391..27a1596d18b616fe8f833cc88e06540b754088bd 100644 (file)
@@ -545,7 +545,7 @@ int mutt_parse_crypt_hdr(const char *p, int set_empty_signas, int crypt_app)
  * @param fp      If not NULL, file containing the template
  * @param ctx     If fp is NULL, the context containing the header with the template
  * @param newhdr  The template is read into this Header
- * @param e     The message to recall/resend
+ * @param e       Email to recall/resend
  * @param resend  Set if resending (as opposed to recalling a postponed msg)
  *                Resent messages enable header weeding, and also
  *                discard any existing Message-ID and Mail-Followup-To
index 06b8b05b0036e2533c9380c73cef3357cb3e4866..e547d43a9f64a0f0f853578cc7b8ece55099e59e 100644 (file)
--- a/recvcmd.c
+++ b/recvcmd.c
@@ -726,8 +726,8 @@ static void attach_forward_msgs(FILE *fp, struct AttachCtx *actx, struct Body *c
 
 /**
  * mutt_attach_forward - Forward an Attachment
- * @param fp    Handle to the attachmenT
- * @param e   Header of message
+ * @param fp    Handle to the attachment
+ * @param e     Email
  * @param actx  Attachment Context
  * @param cur   Current message
  * @param flags Send mode, e.g. #SEND_RESEND
@@ -879,7 +879,7 @@ static void attach_include_reply(FILE *fp, FILE *tmpfp, struct Email *cur)
 /**
  * mutt_attach_reply - Attach a reply
  * @param fp    File handle to reply
- * @param e   Header of message
+ * @param e     Email
  * @param actx  Attachment Context
  * @param cur   Current message
  * @param flags Send mode, e.g. #SEND_RESEND
@@ -1039,7 +1039,7 @@ void mutt_attach_reply(FILE *fp, struct Email *e, struct AttachCtx *actx,
 /**
  * mutt_attach_mail_sender - Compose an email to the sender in the email attachment
  * @param fp   File containing attachment (UNUSED)
- * @param e  Email (UNUSED)
+ * @param e    Email (UNUSED)
  * @param actx Attachment Context
  * @param cur  Current attachment
  */
diff --git a/score.c b/score.c
index 3e6092d542211877b8ab0db3338b72deba83c7e0..db6adbfa6cec0e86ffc696bbe972832fce8e0469 100644 (file)
--- a/score.c
+++ b/score.c
@@ -159,7 +159,7 @@ int mutt_parse_score(struct Buffer *buf, struct Buffer *s, unsigned long data,
 /**
  * mutt_score_message - Apply scoring to an email
  * @param ctx     Mailbox
- * @param e     Email header
+ * @param e     Email
  * @param upd_ctx If true, update the Context too
  */
 void mutt_score_message(struct Context *ctx, struct Email *e, bool upd_ctx)
diff --git a/flags.c b/flags.c
index 0be046a33ea9b53201691cbf14acc84f88a86a4b..8de9a95c7b6d647ccd1977a8c0793a1becb29f52 100644 (file)
--- a/flags.c
+++ b/flags.c
@@ -48,7 +48,7 @@
 /**
  * mutt_set_flag_update - Set a flag on an email
  * @param ctx     Mailbox Context
- * @param e       Email Header
+ * @param e       Email
  * @param flag    Flag to set, e.g. #MUTT_DELETE
  * @param bf      true: set the flag; false: clear the flag
  * @param upd_ctx true: update the Context
@@ -363,7 +363,7 @@ void mutt_tag_set_flag(int flag, int bf)
 
 /**
  * mutt_thread_set_flag - Set a flag on an entire thread
- * @param e       Email Header
+ * @param e         Email
  * @param flag      Flag to set, e.g. #MUTT_DELETE
  * @param bf        true: set the flag; false: clear the flag
  * @param subthread If true apply to all of the thread
@@ -421,7 +421,7 @@ done:
 
 /**
  * mutt_change_flag - Change the flag on a Message
- * @param e  Email Header
+ * @param e  Email
  * @param bf true: set the flag; false: clear the flag
  * @retval  0 Success
  * @retval -1 Failure
index 7f4f5456594979e999be303f3ff9643eb73b5ea7..aa712c24545ebe9156fd483ab972042e913f4e26 100644 (file)
@@ -471,46 +471,47 @@ void serial_restore_body(struct Body *c, const unsigned char *d, int *off, bool
 
 /**
  * serial_dump_envelope - Pack an Envelope into a binary blob
* @param e       Envelope to pack
  * @param d       Binary blob to add to
  * @param off     Offset into the blob
  * @param convert If true, the strings will be converted to utf-8
  * @retval ptr End of the newly packed binary
  */
-unsigned char *serial_dump_envelope(struct Envelope *e, unsigned char *d, int *off, bool convert)
+unsigned char *serial_dump_envelope(struct Envelope *env, unsigned char *d,
+                                    int *off, bool convert)
 {
-  d = serial_dump_address(e->return_path, d, off, convert);
-  d = serial_dump_address(e->from, d, off, convert);
-  d = serial_dump_address(e->to, d, off, convert);
-  d = serial_dump_address(e->cc, d, off, convert);
-  d = serial_dump_address(e->bcc, d, off, convert);
-  d = serial_dump_address(e->sender, d, off, convert);
-  d = serial_dump_address(e->reply_to, d, off, convert);
-  d = serial_dump_address(e->mail_followup_to, d, off, convert);
-
-  d = serial_dump_char(e->list_post, d, off, convert);
-  d = serial_dump_char(e->subject, d, off, convert);
-
-  if (e->real_subj)
-    d = serial_dump_int(e->real_subj - e->subject, d, off);
+  d = serial_dump_address(env->return_path, d, off, convert);
+  d = serial_dump_address(env->from, d, off, convert);
+  d = serial_dump_address(env->to, d, off, convert);
+  d = serial_dump_address(env->cc, d, off, convert);
+  d = serial_dump_address(env->bcc, d, off, convert);
+  d = serial_dump_address(env->sender, d, off, convert);
+  d = serial_dump_address(env->reply_to, d, off, convert);
+  d = serial_dump_address(env->mail_followup_to, d, off, convert);
+
+  d = serial_dump_char(env->list_post, d, off, convert);
+  d = serial_dump_char(env->subject, d, off, convert);
+
+  if (env->real_subj)
+    d = serial_dump_int(env->real_subj - env->subject, d, off);
   else
     d = serial_dump_int(-1, d, off);
 
-  d = serial_dump_char(e->message_id, d, off, false);
-  d = serial_dump_char(e->supersedes, d, off, false);
-  d = serial_dump_char(e->date, d, off, false);
-  d = serial_dump_char(e->x_label, d, off, convert);
+  d = serial_dump_char(env->message_id, d, off, false);
+  d = serial_dump_char(env->supersedes, d, off, false);
+  d = serial_dump_char(env->date, d, off, false);
+  d = serial_dump_char(env->x_label, d, off, convert);
 
-  d = serial_dump_buffer(e->spam, d, off, convert);
+  d = serial_dump_buffer(env->spam, d, off, convert);
 
-  d = serial_dump_stailq(&e->references, d, off, false);
-  d = serial_dump_stailq(&e->in_reply_to, d, off, false);
-  d = serial_dump_stailq(&e->userhdrs, d, off, convert);
+  d = serial_dump_stailq(&env->references, d, off, false);
+  d = serial_dump_stailq(&env->in_reply_to, d, off, false);
+  d = serial_dump_stailq(&env->userhdrs, d, off, convert);
 
 #ifdef USE_NNTP
-  d = serial_dump_char(e->xref, d, off, false);
-  d = serial_dump_char(e->followup_to, d, off, false);
-  d = serial_dump_char(e->x_comment_to, d, off, convert);
+  d = serial_dump_char(env->xref, d, off, false);
+  d = serial_dump_char(env->followup_to, d, off, false);
+  d = serial_dump_char(env->x_comment_to, d, off, convert);
 #endif
 
   return d;
@@ -518,48 +519,48 @@ unsigned char *serial_dump_envelope(struct Envelope *e, unsigned char *d, int *o
 
 /**
  * serial_restore_envelope - Unpack an Envelope from a binary blob
* @param e       Store the unpacked Envelope here
  * @param d       Binary blob to read from
  * @param off     Offset into the blob
  * @param convert If true, the strings will be converted from utf-8
  */
-void serial_restore_envelope(struct Envelope *e, const unsigned char *d, int *off, bool convert)
+void serial_restore_envelope(struct Envelope *env, const unsigned char *d, int *off, bool convert)
 {
   int real_subj_off;
 
-  serial_restore_address(&e->return_path, d, off, convert);
-  serial_restore_address(&e->from, d, off, convert);
-  serial_restore_address(&e->to, d, off, convert);
-  serial_restore_address(&e->cc, d, off, convert);
-  serial_restore_address(&e->bcc, d, off, convert);
-  serial_restore_address(&e->sender, d, off, convert);
-  serial_restore_address(&e->reply_to, d, off, convert);
-  serial_restore_address(&e->mail_followup_to, d, off, convert);
-
-  serial_restore_char(&e->list_post, d, off, convert);
-  serial_restore_char(&e->subject, d, off, convert);
+  serial_restore_address(&env->return_path, d, off, convert);
+  serial_restore_address(&env->from, d, off, convert);
+  serial_restore_address(&env->to, d, off, convert);
+  serial_restore_address(&env->cc, d, off, convert);
+  serial_restore_address(&env->bcc, d, off, convert);
+  serial_restore_address(&env->sender, d, off, convert);
+  serial_restore_address(&env->reply_to, d, off, convert);
+  serial_restore_address(&env->mail_followup_to, d, off, convert);
+
+  serial_restore_char(&env->list_post, d, off, convert);
+  serial_restore_char(&env->subject, d, off, convert);
   serial_restore_int((unsigned int *) (&real_subj_off), d, off);
 
   if (real_subj_off >= 0)
-    e->real_subj = e->subject + real_subj_off;
+    env->real_subj = env->subject + real_subj_off;
   else
-    e->real_subj = NULL;
+    env->real_subj = NULL;
 
-  serial_restore_char(&e->message_id, d, off, false);
-  serial_restore_char(&e->supersedes, d, off, false);
-  serial_restore_char(&e->date, d, off, false);
-  serial_restore_char(&e->x_label, d, off, convert);
+  serial_restore_char(&env->message_id, d, off, false);
+  serial_restore_char(&env->supersedes, d, off, false);
+  serial_restore_char(&env->date, d, off, false);
+  serial_restore_char(&env->x_label, d, off, convert);
 
-  serial_restore_buffer(&e->spam, d, off, convert);
+  serial_restore_buffer(&env->spam, d, off, convert);
 
-  serial_restore_stailq(&e->references, d, off, false);
-  serial_restore_stailq(&e->in_reply_to, d, off, false);
-  serial_restore_stailq(&e->userhdrs, d, off, convert);
+  serial_restore_stailq(&env->references, d, off, false);
+  serial_restore_stailq(&env->in_reply_to, d, off, false);
+  serial_restore_stailq(&env->userhdrs, d, off, convert);
 
 #ifdef USE_NNTP
-  serial_restore_char(&e->xref, d, off, false);
-  serial_restore_char(&e->followup_to, d, off, false);
-  serial_restore_char(&e->x_comment_to, d, off, convert);
+  serial_restore_char(&env->xref, d, off, false);
+  serial_restore_char(&env->followup_to, d, off, false);
+  serial_restore_char(&env->x_comment_to, d, off, convert);
 #endif
 }
 
@@ -471,46 +471,47 @@ void serial_restore_body(struct Body *c, const unsigned char *d, int *off, bool
 /**
  * serial_dump_envelope - Pack an Envelope into a binary blob
- * @param e       Envelope to pack
+ * @param env     Envelope to pack
  * @param d       Binary blob to add to
  * @param off     Offset into the blob
@@ -518,48 +519,48 @@ unsigned char *serial_dump_envelope(struct Envelope *e, unsigned char *d, int *o
 /**
  * serial_restore_envelope - Unpack an Envelope from a binary blob
- * @param e       Store the unpacked Envelope here
+ * @param env     Store the unpacked Envelope here
  * @param d       Binary blob to read from
  * @param off     Offset into the blob
diff --git a/send.c b/send.c
index c8b77756d4706178e4dfc5b9a38e8affdef98e41..8cff07125d98a96d73f7466a1cfa381f9de2c0b1 100644 (file)
--- a/send.c
+++ b/send.c
@@ -786,13 +786,13 @@ int mutt_fetch_recips(struct Envelope *out, struct Envelope *in, int flags)
 /**
  * add_references - Add the email's references to a list
  * @param head List of references
* @param e    Envelope of message
  */
-static void add_references(struct ListHead *head, struct Envelope *e)
+static void add_references(struct ListHead *head, struct Envelope *env)
 {
   struct ListNode *np = NULL;
 
-  struct ListHead *src = !STAILQ_EMPTY(&e->references) ? &e->references : &e->in_reply_to;
+  struct ListHead *src = !STAILQ_EMPTY(&env->references) ? &env->references : &env->in_reply_to;
   STAILQ_FOREACH(np, src, entries)
   {
     mutt_list_insert_tail(head, mutt_str_strdup(np->data));
@@ -802,13 +802,13 @@ static void add_references(struct ListHead *head, struct Envelope *e)
 /**
  * add_message_id - Add the email's message ID to a list
  * @param head List of message IDs
* @param e    Envelope of message
  */
-static void add_message_id(struct ListHead *head, struct Envelope *e)
+static void add_message_id(struct ListHead *head, struct Envelope *env)
 {
-  if (e->message_id)
+  if (env->message_id)
   {
-    mutt_list_insert_head(head, mutt_str_strdup(e->message_id));
+    mutt_list_insert_head(head, mutt_str_strdup(env->message_id));
   }
 }
 
@@ -1145,9 +1145,9 @@ static int generate_body(FILE *tempfp, struct Email *msg, int flags,
 
 /**
  * mutt_set_followup_to - Set followup-to field
* @param e Envelope to modify
  */
-void mutt_set_followup_to(struct Envelope *e)
+void mutt_set_followup_to(struct Envelope *env)
 {
   struct Address *t = NULL;
   struct Address *from = NULL;
@@ -1161,26 +1161,26 @@ void mutt_set_followup_to(struct Envelope *e)
 #ifdef USE_NNTP
   if (OptNewsSend)
   {
-    if (!e->followup_to && e->newsgroups && (strrchr(e->newsgroups, ',')))
-      e->followup_to = mutt_str_strdup(e->newsgroups);
+    if (!env->followup_to && env->newsgroups && (strrchr(env->newsgroups, ',')))
+      env->followup_to = mutt_str_strdup(env->newsgroups);
     return;
   }
 #endif
 
-  if (!e->mail_followup_to)
+  if (!env->mail_followup_to)
   {
-    if (mutt_is_list_cc(0, e->to, e->cc))
+    if (mutt_is_list_cc(0, env->to, env->cc))
     {
       /* this message goes to known mailing lists, so create a proper
        * mail-followup-to header
        */
 
-      t = mutt_addr_append(&e->mail_followup_to, e->to, false);
-      mutt_addr_append(&t, e->cc, true);
+      t = mutt_addr_append(&env->mail_followup_to, env->to, false);
+      mutt_addr_append(&t, env->cc, true);
     }
 
     /* remove ourselves from the mail-followup-to header */
-    e->mail_followup_to = remove_user(e->mail_followup_to, false);
+    env->mail_followup_to = remove_user(env->mail_followup_to, false);
 
     /* If we are not subscribed to any of the lists in question,
      * re-add ourselves to the mail-followup-to header.  The
@@ -1188,12 +1188,12 @@ void mutt_set_followup_to(struct Envelope *e)
      * but makes sure list-reply has the desired effect.
      */
 
-    if (e->mail_followup_to && !mutt_is_list_recipient(false, e->to, e->cc))
+    if (env->mail_followup_to && !mutt_is_list_recipient(false, env->to, env->cc))
     {
-      if (e->reply_to)
-        from = mutt_addr_copy_list(e->reply_to, false);
-      else if (e->from)
-        from = mutt_addr_copy_list(e->from, false);
+      if (env->reply_to)
+        from = mutt_addr_copy_list(env->reply_to, false);
+      else if (env->from)
+        from = mutt_addr_copy_list(env->from, false);
       else
         from = mutt_default_from();
 
@@ -1203,12 +1203,12 @@ void mutt_set_followup_to(struct Envelope *e)
         for (t = from; t && t->next; t = t->next)
           ;
 
-        t->next = e->mail_followup_to; /* t cannot be NULL at this point. */
-        e->mail_followup_to = from;
+        t->next = env->mail_followup_to; /* t cannot be NULL at this point. */
+        env->mail_followup_to = from;
       }
     }
 
-    e->mail_followup_to = mutt_addrlist_dedupe(e->mail_followup_to);
+    env->mail_followup_to = mutt_addrlist_dedupe(env->mail_followup_to);
   }
 }
@@ -786,13 +786,13 @@ int mutt_fetch_recips(struct Envelope *out, struct Envelope *in, int flags)
  * add_references - Add the email's references to a list
  * @param head List of references
- * @param e    Envelope of message
+ * @param env    Envelope of message
  */
@@ -802,13 +802,13 @@ static void add_references(struct ListHead *head, struct Envelope *e)
  * add_message_id - Add the email's message ID to a list
  * @param head List of message IDs
- * @param e    Envelope of message
+ * @param env  Envelope of message
  */
@@ -1145,9 +1145,9 @@ static int generate_body(FILE *tempfp, struct Email *msg, int flags,
 /**
  * mutt_set_followup_to - Set followup-to field
- * @param e Envelope to modify
+ * @param env Envelope to modify
  */